@@ -32,10 +32,6 @@ PROGBAR_BG_LEFT = '\033[48;5;240m'
 PROGBAR_FG_RIGHT = '\033[38;5;16m'
 PROGBAR_FG_LEFT = '\033[38;5;231m'
 
-COLOR_NEGATIVE = '\033[38;5;1m'
-COLOR_NEUTRAL = '\033[38;5;0m'
-COLOR_POSITIVE = '\033[38;5;2m'
-
 PROGBAR_INIT = 0
 PROGBAR_ACTIVE = 1
 PROGBAR_DONE = 2
@@ -164,3 +160,7 @@ else:
     COLOR_DEFAULT_FONT_BG = ''
 
 RED = _parse_font_color_from_rgb((170/255, 0, 0))
+
+COLOR_NEGATIVE = '\033[38;5;1m'
+COLOR_NEUTRAL = '\033[38;5;240m'  # RESET  # '\033[38;5;0m'
+COLOR_POSITIVE = '\033[38;5;2m'
